fflas_ffpack: Dense linear algebra over word-size finite fields
===============================================================

Description
-----------

FFLAS-FFPACK is a LGPL-2.1+ source code library for dense linear algebra
over word-size finite fields.

http://linbox-team.github.io/fflas-ffpack/

License
-------

LGPL V2.1 or later


SPKG Repository
---------------

   https://bitbucket.org/malb/fflas-ffpack-spkg


Upstream Contact
----------------

-  <ffpack-devel@googlegroups.com>

Dependencies
------------

-  Givaro
-  a BLAS implementation such as openblas


Patches
-------

-  bash.patch: fix shebang line to "#!/usr/bin/env bash"
